@@ -7,8 +7,8 @@ import numpy as np
 import pyqsp
 from pyqsp import angle_sequence, response
 from pyqsp.phases import phase_generators
-from pyqsp.poly import polynomial_generators
-from pyqsp.poly import StringPolynomial, TargetPolynomial
+from pyqsp.poly import (StringPolynomial, TargetPolynomial,
+                        polynomial_generators)
 
 # -----------------------------------------------------------------------------
 
@@ -40,6 +40,7 @@ Commands:
     angles      - generate QSP phase angles for the specified --seqname and --seqargs
     poly        - generate QSP phase angles for the specified --polyname and --polyargs, e.g. sign and threshold polynomials
     polyfunc    - generate QSP phase angles for the specified --func and --polydeg using tensorflow + keras optimization method (--tf)
+    response    - generate QSP polynomial response functions for the QSP phase angles specified by --phiset
 
 Examples:
 
@@ -57,6 +58,7 @@ Examples:
     pyqsp --plot-positive-only --plot-real-only --plot --polyargs 20,0.2,0.9 --polyname efilter poly
     pyqsp --plot-positive-only --plot --polyargs=19,10 --plot-real-only --polyname poly_sign --method tf poly
     pyqsp --plot --func "np.cos(3*x)" --polydeg 6 polyfunc
+    pyqsp --plot --func "np.cos(3*x)" --polydeg 6 --plot-qsp-model polyfunc
     pyqsp --plot-positive-only --plot-real-only --plot --polyargs 20,3.5 --polyname gibbs --plot-qsp-model poly
 
 """.format(version)
@@ -66,7 +68,17 @@ Examples:
         formatter_class=argparse.RawTextHelpFormatter)
 
     def float_list(value):
-        return list(map(float, value.split(",")))
+        try:
+            if not ',' in value and value.startswith("[") and value.endswith("]"):
+                fstrset = value[1:-1].split(" ")
+                fstrset = [x for x in fstrset if x]
+                flist = list(map(float, fstrset))
+                return flist
+            return list(map(float, value.split(",")))
+        except Exception as err:
+            print(
+                f"[pyqsp.float_list] failed to parse float list, err={err} from {value}")
+            raise
 
     parser.add_argument("cmd", help="command")
     parser.add_argument(
@@ -141,6 +153,10 @@ Examples:
         "--plot-magnitude",
         help="when plotting only show magnitude, instead of separate imaginary and real components",
         action="store_true")
+    parser.add_argument(
+        "--plot-probability",
+        help="when plotting only show squared magnitude, instead of separate imaginary and real components",
+        action="store_true")
     parser.add_argument(
         "--plot-real-only",
         help="when plotting only real component, and not imaginary",
@@ -176,12 +192,28 @@ Examples:
         "--plot-qsp-model",
         help="show qsp_model version of response plot instead of the default plot",
         action="store_true")
+    parser.add_argument(
+        "--phiset",
+        help="comma delimited list of QSP phase angles, to be used in the 'response' command",
+        action="store",
+        type=float_list)
+    parser.add_argument(
+        "--nepochs",
+        help="number of epochs to use in tensorflow optimization",
+        type=int,
+        default=5000)
+    parser.add_argument(
+        "--npts-theta",
+        help="number of discretized values of theta to use in tensorflow optimization",
+        type=int,
+        default=30)
 
     if not args:
         args = parser.parse_args(arglist)
 
     phiset = None
     plot_args = dict(plot_magnitude=args.plot_magnitude,
+                     plot_probability=args.plot_probability,
                      plot_positive_only=args.plot_positive_only,
                      plot_real_only=args.plot_real_only,
                      plot_tight_y=args.plot_tight_y,
@@ -190,6 +222,13 @@ Examples:
                      show_qsp_model_plot=args.plot_qsp_model,
                      )
 
+    qspp_args = dict(signal_operator=args.signal_operator,
+                     method=args.method,
+                     tolerance=args.tolerance,
+                     nepochs=args.nepochs,
+                     npts_theta=args.npts_theta,
+    )
+
     if args.cmd == "poly2angles":
         coefs = args.poly
         if not coefs:
@@ -200,10 +239,13 @@ Examples:
             coefs = list(map(float, coefs.split(",")))
         print(f"[pyqsp] polynomial coefficients={coefs}")
         phiset = angle_sequence.QuantumSignalProcessingPhases(
-            coefs, signal_operator=args.signal_operator, method=args.method)
+            coefs, **qspp_args)
         if args.plot:
             response.PlotQSPResponse(
-                phiset, pcoefs=coefs, signal_operator=args.signal_operator, **plot_args)
+                phiset,
+                pcoefs=coefs,
+                signal_operator=args.signal_operator,
+                **plot_args)
 
     elif args.cmd == "hamsim":
         pg = pyqsp.poly.PolyCosineTX()
@@ -213,7 +255,7 @@ Examples:
             ensure_bounded=True,
             return_scale=True)
         phiset = angle_sequence.QuantumSignalProcessingPhases(
-            pcoefs, tolerance=args.tolerance, method=args.method)
+            pcoefs, **qspp_args)
         if args.plot:
             response.PlotQSPResponse(
                 phiset,
@@ -229,7 +271,7 @@ Examples:
             ensure_bounded=True,
             return_scale=True)
         phiset = angle_sequence.QuantumSignalProcessingPhases(
-            pcoefs, tolerance=args.tolerance, method=args.method)
+            pcoefs, **qspp_args)
         if args.plot:
             response.PlotQSPResponse(
                 phiset,
@@ -257,12 +299,13 @@ Examples:
             ensure_bounded=True,
             return_scale=True)
         phiset = angle_sequence.QuantumSignalProcessingPhases(
-            pcoefs, tolerance=args.tolerance, method=args.method)
+            pcoefs, **qspp_args)
         if args.plot:
             response.PlotQSPResponse(
                 phiset,
-                target=lambda x: scale * 1/x,
+                target=lambda x: scale * 1 / x,
                 signal_operator="Wx",
+                measurement="z",
                 title="Inversion",
                 **plot_args)
 
@@ -273,11 +316,11 @@ Examples:
             ensure_bounded=True,
             return_scale=True)
         phiset = angle_sequence.QuantumSignalProcessingPhases(
-            pcoefs, tolerance=args.tolerance, method=args.method)
+            pcoefs, **qspp_args)
         if args.plot:
             response.PlotQSPResponse(
                 phiset,
-                target=lambda x: scale * np.exp(-args.seqargs[1]*x),
+                target=lambda x: scale * np.exp(-args.seqargs[1] * x),
                 signal_operator="Wx",
                 title="Gibbs distribution",
                 **plot_args)
@@ -289,7 +332,7 @@ Examples:
             ensure_bounded=True,
             return_scale=True)
         phiset = angle_sequence.QuantumSignalProcessingPhases(
-            pcoefs, tolerance=args.tolerance, method=args.method)
+            pcoefs, **qspp_args)
         if args.plot:
             delta = args.seqargs[1] / 2.
             response.PlotQSPResponse(
@@ -307,7 +350,7 @@ Examples:
             ensure_bounded=True,
             return_scale=True)
         phiset = angle_sequence.QuantumSignalProcessingPhases(
-            pcoefs, tolerance=args.tolerance, method=args.method)
+            pcoefs, **qspp_args)
         if args.plot:
             response.PlotQSPResponse(
                 phiset,
@@ -323,7 +366,7 @@ Examples:
             ensure_bounded=True,
             return_scale=True)
         phiset = angle_sequence.QuantumSignalProcessingPhases(
-            pcoefs, tolerance=args.tolerance, method=args.method)
+            pcoefs, **qspp_args)
         if args.plot:
             response.PlotQSPResponse(
                 phiset,
@@ -339,7 +382,7 @@ Examples:
             ensure_bounded=True,
             return_scale=True)
         phiset = angle_sequence.QuantumSignalProcessingPhases(
-            pcoefs, tolerance=args.tolerance, method=args.method)
+            pcoefs, **qspp_args)
         if args.plot:
             response.PlotQSPResponse(
                 phiset,
@@ -356,13 +399,13 @@ Examples:
             ensure_bounded=True,
             return_scale=True)
         phiset = angle_sequence.QuantumSignalProcessingPhases(
-            pcoefs, tolerance=args.tolerance, method=args.method)
+            pcoefs, **qspp_args)
         if args.plot:
             response.PlotQSPResponse(
                 phiset,
                 target=lambda x: scale *
-                1 - (np.sign(x + 1/args.kappa) -
-                     np.sign(x - 1/args.kappa)) / 2,
+                1 - (np.sign(x + 1 / args.kappa) -
+                     np.sign(x - 1 / args.kappa)) / 2,
                 signal_operator="Wx",
                 title="Rect Function",
                 **plot_args)
@@ -374,11 +417,11 @@ Examples:
             ensure_bounded=True,
             return_scale=True)
         phiset = angle_sequence.QuantumSignalProcessingPhases(
-            pcoefs, tolerance=args.tolerance, method=args.method)
+            pcoefs, **qspp_args)
         if args.plot:
             response.PlotQSPResponse(
                 phiset,
-                target=lambda x: scale * 1/x,
+                target=lambda x: scale * 1 / x,
                 signal_operator="Wx",
                 title="Poly Rect * 1/x",
                 **plot_args)
@@ -395,13 +438,17 @@ Examples:
         pcoefs = pg.generate(*args.polyargs)
         print(f"[pyqsp] polynomial coefs = {pcoefs}")
         phiset = angle_sequence.QuantumSignalProcessingPhases(
-            pcoefs, tolerance=args.tolerance, method=args.method)
+            pcoefs, **qspp_args)
         if args.plot:
             target = None
             if isinstance(pcoefs, TargetPolynomial):
                 target = pcoefs.target
             response.PlotQSPResponse(
-                phiset, pcoefs=pcoefs, target=target, signal_operator="Wx", **plot_args)
+                phiset,
+                pcoefs=pcoefs,
+                target=target,
+                signal_operator="Wx",
+                **plot_args)
 
     elif args.cmd == "angles":
         if not args.seqname or args.seqname not in phase_generators:
@@ -421,12 +468,21 @@ Examples:
         if (not args.func) or (not args.polydeg):
             print(f"Must specify --func and --polydeg")
             return
+        qspp_args['method'] = 'tf'
         poly = StringPolynomial(args.func, args.polydeg)
-        phiset = angle_sequence.QuantumSignalProcessingPhases(poly, method="tf")
+        phiset = angle_sequence.QuantumSignalProcessingPhases(
+            poly, **qspp_args)
         if args.plot:
             response.PlotQSPResponse(
                 phiset, target=poly, signal_operator="Wx", **plot_args)
 
+    elif args.cmd == "response":
+        if not args.phiset:
+            print("Must specify --phiset")
+        phiset = args.phiset
+        response.PlotQSPResponse(
+            phiset, signal_operator=args.signal_operator, **plot_args)
+
     else:
         print(f"[pyqsp.main] Unknown command {args.cmd}")
         print(help_text)
@@ -437,5 +493,6 @@ Examples:
         if args.output_json:
             print(
                 f"QSP Phase angles (for signal_operator={args.signal_operator}) in JSON format:")
-            phiset = phiset.tolist()
-            print(json.dumps(phiset, indent=4))
+            if not isinstance(phiset, list):
+                phiset = phiset.tolist()
+            print(json.dumps(phiset))
