@@ -40,8 +40,8 @@ def ComputeQSPResponse(
              [1j * np.sqrt(1 - a**2), a]])
 
         def qsp_op(phi): return np.array(
-            [[np.exp(1j*phi), 0.],
-             [0., np.exp(-1j*phi)]])
+            [[np.exp(1j * phi), 0.],
+             [0., np.exp(-1j * phi)]])
     elif signal_operator == "Wz":
         H = np.array([[1, 1], [1, -1]]) / np.sqrt(2)
 
@@ -50,8 +50,8 @@ def ComputeQSPResponse(
              [1j * np.sqrt(1 - a**2), a]]) @ H
 
         def qsp_op(phi): return H @ np.array(
-            [[np.exp(1j*phi), 0.],
-             [0., np.exp(-1j*phi)]]) @ H
+            [[np.exp(1j * phi), 0.],
+             [0., np.exp(-1j * phi)]]) @ H
     else:
         raise ResponseError(
             "Invalid signal_operator: {}".format(signal_operator)
@@ -98,6 +98,7 @@ def PlotQSPResponse(
         show=True,
         title=None,
         plot_magnitude=False,
+        plot_probability=False,
         plot_positive_only=False,
         plot_real_only=False,
         plot_tight_y=False,
@@ -117,11 +118,13 @@ def PlotQSPResponse(
         title: plot title, if provided
         plot_magnitude: if True, show magnitude instead of real and imaginary
             parts
+        plot_probability: if True, show squared magnitude instead of real and
+            imaginary parts
         plot_positive_only: if True, then only show positive ordinate values
         plot_real_only: if True, show only real part
         plot_tight_y: if True, set y-axis scale to be from min to max of real
             part; else go from +1.5 max to -1.5 max
-        show_qsp_model_plot: if True, use qsp_model.plot_qsp_response 
+        show_qsp_model_plot: if True, use qsp_model.plot_qsp_response
 
     Returns:
         Response object.
@@ -129,7 +132,8 @@ def PlotQSPResponse(
 
     if show_qsp_model_plot:
         import pyqsp.qsp_models as qsp_models
-        return qsp_models.plot_qsp_response(target, model=None, phis=phiset, title=title)
+        return qsp_models.plot_qsp_response(
+            target, model=None, phis=phiset, title=title)
 
     if plot_positive_only:
         adat = np.linspace(0., 1., npts)
@@ -162,6 +166,10 @@ def PlotQSPResponse(
         plt.plot(adat, abs(pdat), 'k', label="abs[Poly(a)]")
         ymax = np.max(np.abs(pdat))
         ymin = np.min(np.abs(pdat))
+    elif plot_probability:
+        plt.plot(adat, abs(pdat)**2, 'k', label="abs[Poly(a)]^2")
+        ymax = np.max(np.abs(pdat))**2
+        ymin = np.min(np.abs(pdat))**2
     else:
         plt.plot(adat, np.real(pdat), 'k', label="Re[Poly(a)]")
         if not plot_real_only:
